Stacked Discontinuation Bar Chart
Usage
discontinuation_groupBar(
dfNum,
dfDenom,
varGroupID,
strGroupLabel,
varStatus = compyn,
valuesDiscontinued = c("N")
)Arguments
- dfNum
A
data.framecontaining the participant level dataset with just premature discontinuation- dfDenom
A
data.framecontaining the participant level dataset with all study dispositions- varGroupID
A variable to make the stacked bar chart with, i.e. invid
- strGroupLabel
A
stringto label thevarGroupIDin reference to axes, legend, footnotes.- varStatus
A variable indicating participant study status, defaults to
compyn.- valuesDiscontinued
A vector of values in
varStatusconsidered premature discontinuations, defaults to 'N'.