Stacked Eligibility Bar Chart
Arguments
- dfNum
A
data.framecontaining the participant level dataset with only ineligibility values- dfDenom
A
data.framecontaining the participant level dataset with all inc/exc values.- varGroupID
A variable to make the stacked bar chart with, i.e. invid
- strGroupLabel
A
stringto label thevarGroupIDin reference to axes, legend, footnotes.- bPercentage
A
booleanto denote whether or not the group bar chart should be visualized as percentages instead of absolute counts.